@@ -1,4 +1,4 @@
-# $Id: NodeList.pm,v 1.1 2001/08/07 07:34:24 matt Exp $
+# $Id: NodeList.pm,v 1.3 2002/09/14 20:49:33 phish Exp $
 
 package XML::LibXML::NodeList;
 use strict;
@@ -53,7 +53,9 @@ sub size {
 	scalar @$self;
 }
 
-sub get_node { # uses array index starting at 1, not 0
+sub get_node {
+    # uses array index starting at 1, not 0
+    # this is mainly because of XPath.
 	my $self = CORE::shift;
 	my ($pos) = @_;
 	$self->[$pos - 1];
@@ -81,7 +83,7 @@ sub string_value {
 sub to_literal {
 	my $self = CORE::shift;
 	return XML::LibXML::Literal->new(
-			join('', map { $_->string_value } @$self)
+			join('', grep {defined $_} map { $_->string_value } @$self)
 			);
 }
 
@@ -92,6 +94,77 @@ sub to_number {
 			);
 }
 
+sub iterator {
+    my $self = CORE::shift;
+    return XML::LibXML::NodeList::Iterator->new( $self );
+}
+
+1;
+
+package XML::LibXML::NodeList::Iterator;
+
+use strict;
+
+use overload
+  '++' => sub { $_[0]->next;     $_[0]; },
+  '--' => sub { $_[0]->previous; $_[0] },
+  '<>'  =>  sub {
+      if ( wantarray ) {
+          my @rv = ();
+          while ( $_[0]->next ){ push @rv,$_;}
+          return @rv;
+      } else {
+          return $_[0]->next
+      };
+  },
+;
+
+sub new {
+    my $class = shift;
+    my $list  = shift;
+    my $self  = undef;
+    if ( defined $list ) {
+        $self = bless [
+                       $list,
+                       0
+                      ], $class;
+    }
+    return $self;
+}
+
+sub first    { $_[0][1]=0; return $_[0][0][0]; }
+sub last     { $_[0][1]=scalar(@{$_[0][0]})-1; return $_[0][0][-1]; }
+sub current  { return $_[0][0][$_[0][1]]; }
+sub index    { return $_[0][1]; }
+
+sub next     {
+    if ( (scalar @{$_[0][0]}) <= ($_[0][1] + 1)) {
+        return undef;
+    }
+    $_[0][1]++;
+    return $_[0][0]->[$_[0][1]];
+}
+
+sub previous {
+    if ( $_[0][1] <= 0 ) {
+        return undef;
+    }
+    $_[0][1]--;
+    return $_[0][0][$_[0][1]];
+}
+
+sub iterate  {
+    my $self = shift;
+    my $funcref = shift;
+    return unless defined $funcref && ref( $funcref ) eq 'CODE';
+    $self->[1] = -1;
+    my $rv;
+    while ( $self->next ) {
+        $rv = $funcref->( $self, $_ );
+    }
+    return $rv;
+}
+
 1;
 __END__
 
@@ -167,4 +240,10 @@ Equivalent to perl's unshift function.
 Given a nodelist, prepends the list of nodes in $nodelist to the front of
 the current list.
 
+=head2 iterator()
+
+Will return a new nodelist iterator for the current nodelist. A
+nodelist iterator is usefull if more complex nodelist processing is
+needed.
+
 =cut
