@@ -1,6 +1,6 @@
 /**
  * perl-libxml-mm.c
- * $Id: perl-libxml-mm.c,v 1.35 2003/05/01 21:31:12 phish Exp $
+ * $Id: perl-libxml-mm.c,v 1.32 2002/10/25 10:13:28 phish Exp $
  *
  * Basic concept:
  * perl varies in the implementation of UTF8 handling. this header (together
@@ -174,12 +174,9 @@ PmmNewFragment(xmlDocPtr doc)
     frag   = xmlNewDocFragment( doc );
     retval = PmmNewNode(frag);
 
-    if ( doc != NULL ) {
+    if ( doc ) {
         xs_warn("inc document\n");
-        /* under rare circumstances _private is not set correctly? */
-        if ( doc->_private != NULL ) {
-            PmmREFCNT_inc(((ProxyNodePtr)doc->_private));
-        }
+        PmmREFCNT_inc(((ProxyNodePtr)doc->_private));
         retval->owner = (xmlNodePtr)doc;
     }
 
@@ -207,7 +204,7 @@ PmmFreeNode( xmlNodePtr node )
         }
         break;
     case XML_DTD_NODE:
-        if ( node->doc != NULL ) {
+        if ( node->doc ) {
             if ( node->doc->extSubset != (xmlDtdPtr)node 
                  && node->doc->intSubset != (xmlDtdPtr)node ) {
                 xs_warn( "PFN: XML_DTD_NODE\n");
@@ -237,7 +234,7 @@ PmmREFCNT_dec( ProxyNodePtr node )
     ProxyNodePtr owner = NULL;  
     int retval = 0;
 
-    if ( node != NULL ) {
+    if ( node ) {
         retval = PmmREFCNT(node)--;
         if ( PmmREFCNT(node) <= 0 ) {
             xs_warn( "NODE DELETATION\n" );
@@ -309,7 +306,7 @@ PmmNodeToSv( xmlNodePtr node, ProxyNodePtr owner )
         xs_warn(" return new perl node\n");
         xs_warn( CLASS );
 
-        if ( node->_private != NULL ) { 
+        if ( node->_private ) {
             dfProxy = PmmNewNode(node);
         }
         else {
@@ -407,10 +404,8 @@ PmmSvNodeExt( SV* perlnode, int copy )
         xs_warn("   perlnode found\n" );
         if ( sv_derived_from(perlnode, "XML::LibXML::Node")  ) {
             proxy = SvPROXYNODE(perlnode);
-            if ( proxy != NULL ) {
-                xs_warn( "is a xmlNodePtr structure\n" );
-                retval = PmmNODE( proxy ) ;
-            }
+            xs_warn( "is a xmlNodePtr structure\n" );
+            retval = PmmNODE( proxy ) ;
 
             if ( retval != NULL
                  && ((ProxyNodePtr)retval->_private) != proxy ) {
@@ -471,7 +466,7 @@ PmmSetSvOwner( SV* perlnode, SV* extra )
 void
 PmmFixOwnerList( xmlNodePtr list, ProxyNodePtr parent )
 {
-    if ( list != NULL ) {
+    if ( list ) {
         xmlNodePtr iterator = list;
         while ( iterator != NULL ) {
             switch ( iterator->type ) {
@@ -532,7 +527,7 @@ PmmFixOwner( ProxyNodePtr nodetofix, ProxyNodePtr parent )
             break;
         }
 
-        if ( PmmOWNER(nodetofix) != NULL ) {
+        if ( PmmOWNER(nodetofix) ) {
             oldParent = PmmOWNERPO(nodetofix);
         }
         
@@ -550,7 +545,7 @@ PmmFixOwner( ProxyNodePtr nodetofix, ProxyNodePtr parent )
                 PmmOWNER(nodetofix) = NULL;
             }
             
-            if ( oldParent != NULL && oldParent != nodetofix )
+            if ( oldParent && oldParent != nodetofix )
                 PmmREFCNT_dec(oldParent);
             
             if ( PmmNODE(nodetofix)->type != XML_ATTRIBUTE_NODE
@@ -609,7 +604,7 @@ PmmContextREFCNT_dec( ProxyNodePtr node )
 { 
     xmlParserCtxtPtr libnode = NULL;
     int retval = 0;
-    if ( node != NULL ) {
+    if ( node ) {
         retval = PmmREFCNT(node)--;
         if ( PmmREFCNT(node) <= 0 ) {
             xs_warn( "NODE DELETATION\n" );
@@ -745,9 +740,11 @@ PmmFastDecodeString( int charset,
     }
 
     if ( charset > 1 ) {
+        /* warn( "use document encoding %s", encoding ); */
         coder= xmlGetCharEncodingHandler( charset );
     }
     else if ( charset == XML_CHAR_ENCODING_ERROR ){
+        /* warn("no standard encoding\n"); */
         coder = xmlFindCharEncodingHandler( (const char *) encoding );
     }
     else {
@@ -761,7 +758,7 @@ PmmFastDecodeString( int charset,
         
         xmlBufferCat( in, string );        
         if ( xmlCharEncOutFunc( coder, out, in ) >= 0 ) {
-            retval = xmlCharStrndup(xmlBufferContent(out), xmlBufferLength(out));
+            retval = xmlStrdup(out->content);
         }
         else {
             xs_warn("decoding error \n");
@@ -807,6 +804,7 @@ char*
 PmmDecodeString( const char *encoding, const xmlChar *string){
     char *ret=NULL;
     xmlCharEncoding enc;
+    xmlBufferPtr in = NULL, out = NULL;
     xmlCharEncodingHandlerPtr coder = NULL;
 
     if ( string != NULL ) {
