@@ -1,6 +1,6 @@
 /**
  * perl-libxml-sax.c
- * $Id: perl-libxml-sax.c,v 1.25 2003/05/22 23:23:43 phish Exp $
+ * $Id: perl-libxml-sax.c,v 1.22 2002/10/24 16:47:16 phish Exp $
  */
 
 #ifdef __cplusplus
@@ -203,11 +203,6 @@ PSaxStartPrefix( PmmSAXVectorPtr sax, const xmlChar * prefix,
 
     perl_call_method( "start_prefix_mapping", G_SCALAR | G_EVAL );
     sv_2mortal(rv);
-    if (SvTRUE(ERRSV)) {
-        STRLEN n_a;
-        POPs;
-        croak(SvPV(ERRSV, n_a));
-    }
     FREETMPS ;
     LEAVE ;
 }
@@ -247,13 +242,9 @@ PSaxEndPrefix( PmmSAXVectorPtr sax, const xmlChar * prefix,
     PUTBACK;
 
     perl_call_method( "end_prefix_mapping", G_SCALAR | G_EVAL );
+
     sv_2mortal(rv);
-    if (SvTRUE(ERRSV)) {
-        STRLEN n_a;
-        POPs;
-        croak(SvPV(ERRSV, n_a));
-    }
-    
+
     FREETMPS ;
     LEAVE ;
 }
@@ -357,8 +348,6 @@ PmmGenElementSV( pTHX_ PmmSAXVectorPtr sax, const xmlChar * name )
 {
     HV * retval = newHV();
     SV * tmp;
-    xmlChar * localname = NULL;
-    xmlChar * prefix    = NULL;
 
     xmlNsPtr ns = NULL;
 
@@ -366,8 +355,9 @@ PmmGenElementSV( pTHX_ PmmSAXVectorPtr sax, const xmlChar * name )
         hv_store(retval, "Name", 4,
                  _C2Sv(name, NULL), NameHash);
 
-        localname = xmlSplitQName(NULL, name, &prefix);
-        ns = PmmGetNsMapping( sax->ns_stack, prefix );
+        if ( sax->ns_stack->ns != NULL ) {  
+            ns = sax->ns_stack->ns;
+        }
 
         if ( ns != NULL ) {
             hv_store(retval, "NamespaceURI", 12,
@@ -460,17 +450,15 @@ PmmGenAttributeHashSV( pTHX_ PmmSAXVectorPtr sax,
                 if ( xmlStrEqual( (const xmlChar *)"xmlns", name ) ) {
                     /* a default namespace */
                     PmmAddNamespace( sax, NULL, value, handler);  
-                    /* nsURI = (const xmlChar*)NSDEFAULTURI; */
-                    nsURI = NULL;
-                    hv_store(atV, "Name", 4,
-                             _C2Sv(name, NULL), NameHash);
+                    nsURI = (const xmlChar*)NSDEFAULTURI;
 
                     hv_store(atV, "Prefix", 6,
-                             _C2Sv("", NULL), PrefixHash);
+                             _C2Sv(name, NULL), PrefixHash);
                     hv_store(atV, "LocalName", 9,
-                             _C2Sv(name,NULL), LocalNameHash);
+                             _C2Sv((const xmlChar *)"",NULL), LocalNameHash);
                     hv_store(atV, "NamespaceURI", 12,
-                             _C2Sv("", NULL), NsURIHash);
+                             _C2Sv((const xmlChar *)NSDEFAULTURI,NULL),
+                             NsURIHash);
                     
                 }
                 else if (xmlStrncmp((const xmlChar *)"xmlns:", name, 6 ) == 0 ) {
@@ -478,9 +466,7 @@ PmmGenAttributeHashSV( pTHX_ PmmSAXVectorPtr sax,
                                      localname,
                                      value,
                                      handler);
-
-                    nsURI = (const xmlChar*)NSDEFAULTURI;
-         
+                                      
                     hv_store(atV, "Prefix", 6,
                              _C2Sv(prefix, NULL), PrefixHash);
                     hv_store(atV, "LocalName", 9,
@@ -491,8 +477,6 @@ PmmGenAttributeHashSV( pTHX_ PmmSAXVectorPtr sax,
                 }
                 else if ( prefix != NULL
                           && (ns = PmmGetNsMapping( sax->ns_stack, prefix ) ) ) {
-                    nsURI = ns->href;
-
                     hv_store(atV, "NamespaceURI", 12,
                              _C2Sv(ns->href, NULL), NsURIHash);
                     hv_store(atV, "Prefix", 6,
@@ -501,7 +485,6 @@ PmmGenAttributeHashSV( pTHX_ PmmSAXVectorPtr sax,
                              _C2Sv(localname, NULL), LocalNameHash);
                 }
                 else {
-                    nsURI = NULL;
                     hv_store(atV, "NamespaceURI", 12,
                              _C2Sv((const xmlChar *)"", NULL), NsURIHash);
                     hv_store(atV, "Prefix", 6,
@@ -602,11 +585,6 @@ PSaxStartDocument(void * ctx)
         PUTBACK;
         
         count = perl_call_method( "start_document", G_SCALAR | G_EVAL );
-        if (SvTRUE(ERRSV)) {
-            STRLEN n_a;
-            POPs;
-            croak(SvPV(ERRSV, n_a));
-        }
         
         SPAGAIN;
 
@@ -625,9 +603,9 @@ PSaxStartDocument(void * ctx)
                      _C2Sv((const xmlChar *)"1.0", NULL), VersionHash);
         }
         
-        if ( ctxt->input->encoding != NULL ) {
+        if ( ctxt->encoding != NULL ) {
             hv_store(empty, "Encoding", 8,
-                     _C2Sv(ctxt->input->encoding, NULL), EncodingHash);
+                     _C2Sv(ctxt->encoding, NULL), EncodingHash);
         }
 
         rv = newRV_noinc((SV*)empty);
@@ -637,12 +615,7 @@ PSaxStartDocument(void * ctx)
         
         count = perl_call_method( "xml_decl", G_SCALAR | G_EVAL );
         sv_2mortal(rv);
-        if (SvTRUE(ERRSV)) {
-            STRLEN n_a;
-            POPs;
-            croak(SvPV(ERRSV, n_a));
-        }
-        
+
         FREETMPS ;
         LEAVE ;
     }
@@ -668,12 +641,7 @@ PSaxEndDocument(void * ctx)
     PUTBACK;
 
     count = perl_call_pv( "XML::LibXML::_SAXParser::end_document", G_SCALAR | G_EVAL );
-    if (SvTRUE(ERRSV)) {
-        STRLEN n_a;
-        POPs;
-        croak(SvPV(ERRSV, n_a));
-    }
-    
+
     FREETMPS ;
     LEAVE ;
 
@@ -718,14 +686,8 @@ PSaxStartElement(void *ctx, const xmlChar * name, const xmlChar** attr)
     PUTBACK;
 
     count = perl_call_method( "start_element", G_SCALAR | G_EVAL );
-    sv_2mortal(rv) ;
-
-    if (SvTRUE(ERRSV)) {
-        STRLEN n_a;
-        POPs;
-        croak(SvPV(ERRSV, n_a));
-    }
     
+    sv_2mortal(rv) ;
     FREETMPS ;
     LEAVE ;
 
@@ -758,14 +720,9 @@ PSaxEndElement(void *ctx, const xmlChar * name) {
     PUTBACK;
 
     count = perl_call_method( "end_element", G_SCALAR | G_EVAL );
+
     sv_2mortal(rv);
-    
-    if (SvTRUE(ERRSV)) {
-        STRLEN n_a;
-        POPs;
-        croak(SvPV(ERRSV, n_a));
-    }
-    
+
     FREETMPS ;
     LEAVE ;
 
@@ -808,14 +765,9 @@ PSaxCharacters(void *ctx, const xmlChar * ch, int len) {
         PUTBACK;
 
         count = perl_call_method( "characters", G_SCALAR | G_EVAL );
+
         sv_2mortal(rv);
-        
-        if (SvTRUE(ERRSV)) {
-            STRLEN n_a;
-            POPs;
-            croak(SvPV(ERRSV, n_a));
-        }
-        
+
         FREETMPS ;
         LEAVE ;
 
@@ -852,14 +804,9 @@ PSaxComment(void *ctx, const xmlChar * ch) {
         PUTBACK;
 
         count = perl_call_method( "comment", G_SCALAR | G_EVAL );
+
         sv_2mortal(rv);
-        
-        if (SvTRUE(ERRSV)) {
-            STRLEN n_a;
-            POPs;
-            croak(SvPV(ERRSV, n_a));
-        }
-        
+
         FREETMPS ;
         LEAVE ;
 
@@ -893,12 +840,7 @@ PSaxCDATABlock(void *ctx, const xmlChar * ch, int len) {
         XPUSHs(handler);
         PUTBACK;
         count = perl_call_method( "start_cdata", G_SCALAR | G_EVAL );
-        if (SvTRUE(ERRSV)) {
-            STRLEN n_a;
-            POPs;
-            croak(SvPV(ERRSV, n_a));
-        }
-        
+
         SPAGAIN;        
         PUSHMARK(SP) ;
     
@@ -909,12 +851,7 @@ PSaxCDATABlock(void *ctx, const xmlChar * ch, int len) {
         PUTBACK;
 
         count = perl_call_method( "characters", G_SCALAR | G_EVAL );
-        if (SvTRUE(ERRSV)) {
-            STRLEN n_a;
-            POPs;
-            croak(SvPV(ERRSV, n_a));
-        }
-        
+
         SPAGAIN;        
         PUSHMARK(SP) ;
     
@@ -922,14 +859,9 @@ PSaxCDATABlock(void *ctx, const xmlChar * ch, int len) {
         PUTBACK;
 
         count = perl_call_method( "end_cdata", G_SCALAR | G_EVAL );
+
         sv_2mortal(rv);
-        
-        if (SvTRUE(ERRSV)) {
-            STRLEN n_a;
-            POPs;
-            croak(SvPV(ERRSV, n_a));
-        }
-        
+
         FREETMPS ;
         LEAVE ;
 
@@ -971,12 +903,6 @@ PSaxProcessingInstruction( void * ctx, const xmlChar * target, const xmlChar * d
 
         sv_2mortal(rv);
 
-        if (SvTRUE(ERRSV)) {
-            STRLEN n_a;
-            POPs;
-            croak(SvPV(ERRSV, n_a));
-        }
-        
         FREETMPS ;
         LEAVE ;
     }
@@ -1019,11 +945,6 @@ PmmSaxWarning(void * ctx, const char * msg, ...)
     PUTBACK;
 
     perl_call_pv( "XML::LibXML::_SAXParser::warning", G_SCALAR | G_EVAL );
-    if (SvTRUE(ERRSV)) {
-        STRLEN n_a;
-        POPs;
-        croak(SvPV(ERRSV, n_a));
-    }
     
     FREETMPS ;
     LEAVE ;
@@ -1062,11 +983,6 @@ PmmSaxError(void * ctx, const char * msg, ...)
     XPUSHs(sv_2mortal(newSViv(ctxt->input->col)));
     PUTBACK;
     perl_call_pv( "XML::LibXML::_SAXParser::error", G_SCALAR | G_EVAL );
-    if (SvTRUE(ERRSV)) {
-        STRLEN n_a;
-        POPs;
-        croak(SvPV(ERRSV, n_a));
-    }
     
     FREETMPS ;
     LEAVE ;
@@ -1103,11 +1019,6 @@ PmmSaxFatalError(void * ctx, const char * msg, ...)
     XPUSHs(sv_2mortal(newSViv(ctxt->input->col)));
     PUTBACK;
     perl_call_pv( "XML::LibXML::_SAXParser::fatal_error", G_SCALAR | G_EVAL );
-    if (SvTRUE(ERRSV)) {
-        STRLEN n_a;
-        POPs;
-        croak(SvPV(ERRSV, n_a));
-    }
     
     FREETMPS ;
     LEAVE ;
